'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.buildFieldConfigArgumentMap = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.default = buildFieldConfigMap;

var _buildASTSchema = require('graphql/utilities/buildASTSchema');

var _produceType = require('./produceType');

var _produceType2 = _interopRequireDefault(_produceType);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var buildFieldConfigArgumentMap = exports.buildFieldConfigArgumentMap = function buildFieldConfigArgumentMap(fieldAST, types) {
  return fieldAST.arguments.reduce(function (map, inputValueAST) {
    var type = (0, _produceType2.default)(inputValueAST.type, types);
    var defaultValue = inputValueAST.defaultValue;
    var description = (0, _buildASTSchema.getDescription)(inputValueAST);
    var argumentConfig = { type: type };
    if (defaultValue !== null) argumentConfig.defaultValue = type.parseLiteral(defaultValue);
    if (description) argumentConfig.description = description;
    return _extends({}, map, _defineProperty({}, inputValueAST.name.value, argumentConfig));
  }, {});
};

function buildFieldConfigMap(objectAST) {
  var configMap = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];
  var types = arguments[2];

  return objectAST.fields.reduce(function (map, fieldAST) {
    var name = fieldAST.name.value;
    var config = configMap[name] || {};
    var type = (0, _produceType2.default)(fieldAST.type, types);
    var args = buildFieldConfigArgumentMap(fieldAST, types);
    var description = (0, _buildASTSchema.getDescription)(fieldAST);
    var fieldConfig = { type: type };
    if (Object.keys(args).length) fieldConfig.args = args;
    if ('resolve' in config) fieldConfig.resolve = config.resolve;
    if ('deprecationReason' in config) fieldConfig.deprecationReason = config.deprecationReason;
    if (description) fieldConfig.description = description;
    return _extends({}, map, _defineProperty({}, name, fieldConfig));
  }, {});
}