'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = buildObject;

var _type = require('graphql/type');

var _buildASTSchema = require('graphql/utilities/buildASTSchema');

var _produceType = require('./produceType');

var _produceType2 = _interopRequireDefault(_produceType);

var _buildFieldConfigMap = require('./buildFieldConfigMap');

var _buildFieldConfigMap2 = _interopRequireDefault(_buildFieldConfigMap);

var _resolveShortcut = require('./resolveShortcut');

var _resolveShortcut2 = _interopRequireDefault(_resolveShortcut);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function buildObject(objectAST) {
  var config = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];
  var types = arguments[2];

  var objectTypeConfig = { name: objectAST.name.value };
  var interfaces = objectAST.interfaces;
  var description = (0, _buildASTSchema.getDescription)(objectAST);
  if (interfaces.length) {
    objectTypeConfig.interfaces = function () {
      return interfaces.map(function (typeAST) {
        return (0, _produceType2.default)(typeAST, types);
      });
    };
  }
  if (!('fields' in config) && !('isTypeOf' in config)) {
    // `resolve` shortcut
    objectTypeConfig.fields = function () {
      return (0, _buildFieldConfigMap2.default)(objectAST, (0, _resolveShortcut2.default)(config), types);
    };
  } else {
    objectTypeConfig.fields = function () {
      return (0, _buildFieldConfigMap2.default)(objectAST, config.fields, types);
    };
    objectTypeConfig.isTypeOf = config.isTypeOf;
  }
  if (description) objectTypeConfig.description = description;
  return new _type.GraphQLObjectType(objectTypeConfig);
}